@@ -1,6 +1,6 @@
 """Async library to fetch info about stops from Yandex Maps."""
 
-__version__ = "1.1.0"
+__version__ = "1.2.3"
 __author__ = "Ivan Belokobylskiy"
 __author_email__ = "belokobylskij@gmail.com"
 __license__ = "MIT"
@@ -16,7 +16,7 @@ from urllib.parse import urlencode
 import aiohttp
 
 DEFAULT_USER_AGENT = "https://pypi.org/project/aiomaps/"
-RESOURCE = "https://yandex.ru/maps/api/masstransit/getStopInfo"
+RESOURCE_PATH = "maps/api/masstransit/getStopInfo"
 AJAX_KEY = "ajax"
 LANG_KEY = "lang"
 LOCALE_KEY = "locale"
@@ -24,8 +24,8 @@ MODE_KEY = "mode"
 SIGNATURE = "s"
 
 CONFIG = {
-    "init_url": "https://maps.yandex.ru",
-    "uri": RESOURCE,
+    # this url bypasses bot checking in yandex
+    "init_url": "https://yandex.ru/maps/2/moscow/",
     "params": {
         AJAX_KEY: 1,
         LANG_KEY: "ru",
@@ -52,23 +52,8 @@ SCHEMA = [
 ]
 
 
-class Prompt:
-    """
-    An async replacement for built-in input(),
-    used for manual captcha resolving
-    """
-
-    def __init__(self, loop=None):
-        self.loop = loop or asyncio.get_event_loop()
-        self.q = asyncio.Queue(loop=self.loop)
-        self.loop.add_reader(sys.stdin, self.got_input)
-
-    def got_input(self):
-        asyncio.ensure_future(self.q.put(sys.stdin.readline()), loop=self.loop)
-
-    async def __call__(self, msg, end="\n", flush=False):
-        print(msg, end=end, flush=flush)
-        return (await self.q.get()).rstrip("\n")
+class CaptchaError(ValueError):
+    pass
 
 
 class YandexMapsRequester:
@@ -90,6 +75,10 @@ class YandexMapsRequester:
             self.client_session = aiohttp.ClientSession(
                 requote_redirect_url=False,
             )
+        # helps to avoid captcha by default (multiple requests still cause it)
+        self.client_session.cookie_jar.update_cookies({
+            "yandexuid": "1234567890123456789",
+        })
 
     async def close(self):
         await self.client_session.close()
@@ -97,15 +86,17 @@ class YandexMapsRequester:
     async def set_new_session(self):
         """Initialize new session to API."""
         async with self.client_session.get(
-            self._config["init_url"], headers=self._config["headers"],
+            self._config["init_url"], headers=self._config["headers"]
         ) as resp:
+            domain = resp.url.host
             reply = await resp.text()
             if 'captcha' in str(resp.real_url):
-                raise ValueError("Captcha required")
+                raise CaptchaError("Captcha required")
 
         result = re.search(rf'"{CSRF_TOKEN_KEY}":"(\w+.\w+)"', reply)
         self._config[PARAMS][CSRF_TOKEN_KEY] = result.group(1)
         self._config["cookies"] = dict(resp.cookies)
+        self._config['uri'] = f'https://{domain}/{RESOURCE_PATH}'
         self._config[PARAMS][SESSION_KEY] = re.search(
             rf'"{SESSION_KEY}":"(\d+.\d+)"', reply
         ).group(1)
